@@ -19,9 +19,12 @@
 
 DELIMITER /
 
-insert into KRCR_CMPNT_T (NMSPC_CD, CMPNT_CD, NM, ACTV_IND, OBJ_ID, VER_NBR)
-VALUES ('KR-WKFLW', 'Rule', 'Rule', 'Y', uuid(), 1)
+-- Make typ_id column optional where appropriate
+
+ALTER TABLE krms_rule_t MODIFY typ_id varchar(40) default null
 /
-update KRCR_CMPNT_T set cmpnt_cd='EDocLite' where cmpnt_cd like 'EDocLite%'
+ALTER TABLE krms_agenda_t MODIFY typ_id varchar(40) default null
+/
+ALTER TABLE krms_cntxt_t MODIFY typ_id varchar(40) default null
 /
 DELIMITER ;
