@@ -19,8 +19,11 @@
 
 DELIMITER /
 
-ALTER TABLE krns_sesn_doc_t ADD (OBJ_ID VARCHAR(36))
-/
-ALTER TABLE krns_sesn_doc_t ADD (VER_NBR DECIMAL(8) DEFAULT 0)
+
+--
+--  KULRICE-7375: Rice master data source has KREW_DOC_TYP_PROC_T.INIT_RTE_NODE_ID still defined as a NUMBER
+--
+
+alter table KREW_DOC_TYP_PROC_T modify column INIT_RTE_NODE_ID varchar(40)
 /
 DELIMITER ;
